#' jab.adverse.reactions: Possible adverse events/reactions from the vaccinations/experimental gene therapies
#'
#' jab.adverse.reactions provides a single table that contains data about the
#' possible adverse events/reactions due to being injected with a
#' vaccine/experimental gene therapy shot.
#'
#'
#'
#' @keywords internal
"_PACKAGE"
#> [1] "_PACKAGE"
